@@ -83,6 +83,12 @@ Summary
    EmptyCommentViolation
    BitwiseAndBooleanMixupViolation
    NewStyledDecoratorViolation
+   BareRaiseViolation
+   RedundantEnumerateViolation
+   RaiseFromItselfViolation
+   KwargsUnpackingInClassDefinitionViolation
+   ConsecutiveSlicesViolation
+   GettingElementByUnpackingViolation
 
 Best practices
 --------------
@@ -154,6 +160,12 @@ Best practices
 .. autoclass:: EmptyCommentViolation
 .. autoclass:: BitwiseAndBooleanMixupViolation
 .. autoclass:: NewStyledDecoratorViolation
+.. autoclass:: BareRaiseViolation
+.. autoclass:: RedundantEnumerateViolation
+.. autoclass:: RaiseFromItselfViolation
+.. autoclass:: KwargsUnpackingInClassDefinitionViolation
+.. autoclass:: ConsecutiveSlicesViolation
+.. autoclass:: GettingElementByUnpackingViolation
 
 """
 
@@ -299,7 +311,7 @@ class OveruseOfNoCoverCommentViolation(SimpleViolation):
 
     """
 
-    error_template = 'Found `noqa` comments overuse: {0}'
+    error_template = 'Found `no cover` comments overuse: {0}'
     code = 403
 
 
@@ -1422,13 +1434,14 @@ class ReassigningVariableToItselfViolation(ASTViolation):
         # Correct:
         some = some + 1
         x_coord, y_coord = y_coord, x_coord
+        flag = not flag
 
         # Wrong:
         some = some
         x_coord, y_coord = x_coord, y_coord
 
     .. versionadded:: 0.3.0
-    .. versionchanged:: 0.11.0
+    .. versionchanged:: 0.16.0
 
     """
 
@@ -2572,3 +2585,188 @@ class NewStyledDecoratorViolation(ASTViolation):
 
     error_template = 'Found new-styled decorator'
     code = 466
+
+
+@final
+class BareRaiseViolation(ASTViolation):
+    """
+    Forbid using a bare ``raise`` keyword outside of ``except``.
+
+    Reasoning:
+       Using a bare ``raise`` outside of an ``except`` block
+       causes a runtime error.
+
+    Solution:
+        Only use bare ``raise`` within an ``except`` block.
+
+    Example::
+
+        # Correct:
+        def smth():
+            try:
+                ...
+            except:
+                raise
+
+        # Wrong:
+        def smth():
+            raise
+
+    .. versionadded:: 0.16.0
+
+    """
+
+    error_template = 'Found bare raise keyword'
+    code = 467
+
+
+@final
+class RedundantEnumerateViolation(ASTViolation):
+    """
+    Forbid using a placeholder (``_``) with ``enumerate``.
+
+    Reasoning:
+       This adds no value and introduces additional complexity.
+
+    Solution:
+        Only use ``enumerate`` when you are going to do something with the
+        index it returns.
+
+    Example::
+
+        # Correct:
+        for item in items:
+          ...
+
+        # Wrong:
+        for _, item in enumerate(items):
+          ...
+
+    .. versionadded:: 0.16.0
+
+    """
+
+    error_template = 'Found redundant use of `enumerate`'
+    code = 468
+
+
+@final
+class RaiseFromItselfViolation(ASTViolation):
+    """
+    Forbid raising an exception from itself.
+
+    Reasoning:
+        It doesn't make sense to raise an exception from it self,
+        since the final behavior will be the same.
+
+    Solution:
+        Don't raise an exeception from itself.
+
+    Example::
+
+        # Correct:
+        ex = Exception('Some Exception')
+        raise ex
+
+        # Wrong:
+        ex = Exception('Some Exception')
+        raise ex from ex
+
+    .. versionadded:: 0.16.0
+
+    """
+
+    error_template = 'Found error raising from itself'
+    code = 469
+
+
+@final
+class KwargsUnpackingInClassDefinitionViolation(ASTViolation):
+    """
+    Forbid kwarg unpacking in class definition.
+
+    Reasoning:
+        Dynamic class generation with unknown arguments is bad because it
+        creates too much flexibility and possibilities for errors.
+        It also limits the typechecking capabilities.
+
+    Solution:
+        Use keyword arguments noramlly without unpacking them.
+
+    Example::
+
+        # Correct:
+        class MyClass(argument='argument'):
+            ...
+
+        # Wrong:
+        arguments = {'argument': 'argument'}
+        class MyClass(**arguments):
+            ...
+
+    .. versionadded:: 0.16.0
+
+    """
+
+    error_template = 'Found kwarg unpacking in class definition'
+    code = 470
+
+
+@final
+class ConsecutiveSlicesViolation(ASTViolation):
+    """
+    Forbid consecutive slices.
+
+    Reasoning:
+        Consecutive slices reduce readability of the code and obscure
+        intended meaning of the expression.
+
+    Solution:
+        Compress multiple consecutive slices into a single one.
+
+    Example::
+
+        # Correct:
+        my_list[1:3]
+
+        # Wrong:
+        my_list[1:][:2]
+
+    .. versionadded:: 0.16.0
+
+    """
+
+    error_template = 'Found consecutive slices'
+    code = 471
+
+
+@final
+class GettingElementByUnpackingViolation(ASTViolation):
+    """
+    Forbid getting first element using unpacking.
+
+    Reasoning:
+        Performance. Prefixing unused variables with underscore is nothing
+        more than convention, Python still creates these variables.
+        So, unpacking above makes a new unused list which is slow.
+
+    Solution:
+        Use `collection[0]` or `next(iter(collection))`
+
+    Example::
+
+        # Correct:
+        first = some_collection[0]
+        first = next(iter(collection))
+
+        # Wrong:
+        first, *_rest = some_collection
+
+    .. versionadded:: 0.16.0
+
+    """
+
+    error_template = (
+        'Found unpacking used to get a single element from a collection'
+    )
+    code = 472
